==> causeway-bom-2.1.0-source-release.zip: causeway-bom-2.1.0/viewers/wicket/viewer/src/main/java/org/apache/causeway/viewer/wicket/viewer/wicketapp/config/DebugInitWkt.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.apache.causeway.viewer.wicket.viewer.wicketapp.config;

import javax.inject.Inject;

import org.apache.wicket.devutils.debugbar.DebugBarInitializer;
import org.apache.wicket.protocol.http.WebApplication;

import org.springframework.context.annotation.Configuration;

import org.apache.causeway.core.config.CausewayConfiguration;
import org.apache.causeway.core.config.environment.CausewaySystemEnvironment;
import org.apache.causeway.viewer.wicket.model.causeway.WicketApplicationInitializer;

@Configuration
public class DebugInitWkt implements WicketApplicationInitializer {

    @Inject private CausewaySystemEnvironment systemEnvironment;
    @Inject private CausewayConfiguration configuration;

    @Override
    public void init(final WebApplication webApplication) {

        webApplication.getDebugSettings()
            .setAjaxDebugModeEnabled(configuration.getViewer().getWicket().isAjaxDebugMode());

        if(systemEnvironment.isPrototyping()
                && configuration.getViewer().getWicket().getDevelopmentUtilities().isEnable()) {
            new DebugBarInitializer().init(webApplication);
        }
    }

}

==> causeway-bom-3.5.0-source-release.zip: causeway-bom-3.5.0/viewers/wicket/viewer/src/main/java/org/apache/causeway/viewer/wicket/viewer/wicketapp/config/DebugInitWkt.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.apache.causeway.viewer.wicket.viewer.wicketapp.config;

import jakarta.inject.Inject;

import org.apache.wicket.devutils.debugbar.DebugBarInitializer;
import org.apache.wicket.protocol.http.WebApplication;

import org.springframework.context.annotation.Configuration;

import org.apache.causeway.core.config.CausewayConfiguration;
import org.apache.causeway.core.config.environment.CausewaySystemEnvironment;
import org.apache.causeway.viewer.wicket.model.causeway.WicketApplicationInitializer;

@Configuration
public class DebugInitWkt implements WicketApplicationInitializer {

    @Inject private CausewaySystemEnvironment systemEnvironment;
    @Inject private CausewayConfiguration configuration;

    @Override
    public void init(final WebApplication webApplication) {

        webApplication.getDebugSettings()
            .setAjaxDebugModeEnabled(configuration.getViewer().getWicket().isAjaxDebugMode());

        if(systemEnvironment.isPrototyping()
                && configuration.getViewer().getWicket().getDevelopmentUtilities().isEnable()) {
            new DebugBarInitializer().init(webApplication);
        }
    }

}
